use ExtUtils::MakeMaker qw(prompt WriteMakefile);

#--- Check for required modules ---

my $missing = 0;
$| = 1;

sub check_module {
  my($module,$version) = @_;
  print substr("$module ............................",0,30);
  my $ok = eval {
    my $file = $module;
    $file =~ s#::#/#g;
    require $file . ".pm";
    $module->VERSION($version) if defined $version;
    1;
  };
  $missing++ unless $ok;
  print $ok ? "ok\n" : "** FAILED **\n$@\n";
  $ok;
}

print "\nChecking for installed modules\n\n";

check_module('Net::LDAP',0.20) or print <<"EDQ","\n";
Net::LDAP version 0.20 or later is essential for ldap-abook
EDQ

check_module('AddressBook',0.15) or print <<"EDQ","\n";
AddressBook version 0.15 or later is essential for ldap-abook
EDQ

print "\n",<<"EDQ","\n" if $missing;
****************************************************************************
You are missing some modules that may be needed for the modules in ldap-abook
to work correctly. Read the above messages and download any required
modules from http://www.perl.com/CPAN
****************************************************************************
EDQ

#--- Do configuration ---

%conf = (
	 "cgi-bin" => "/home/httpd/cgi-bin",
	 );
$r = prompt("Configure ldap-abook now?", "Y");
$r = lc(substr($r, 0, 1));

if($r eq 'y') {
  $conf{"cgi-bin"}   = prompt("CGI bin directory (none = do not install):",
			      $conf{cgi-bin});
}

%MakeArgs = (
    'NAME'	=> 'ldap-abook',
    'DISTNAME' => 'ldap-abook',
    'NORECURS' => 1,
    'AUTHOR'   => 'David Leigh <dleigh@sameasiteverwas.net>',
    'PREREQ_PM' => { 'Net::LDAP' => '0.20',
		     'AddressBook' => '0.15',
		   },
    'VERSION_FROM' => 'cgi-bin/abook.cgi',
);

unless($conf{"cgi-bin"} eq "none") {
  $MakeArgs{'EXE_FILES'} = ['cgi-bin/abook.cgi'];
  $MakeArgs{'INSTALLSCRIPT'} = $conf{"cgi-bin"};
}

WriteMakefile(%MakeArgs);
